ColorSpec

Struct ColorSpec 

pub struct ColorSpec { /* private fields */ }
A color specification.

Implementations

Source

impl ColorSpec

pub fn new() -> ColorSpec

Create a new color specification that has no colors or styles.

pub fn fg(&self) -> Option<&Color>

Get the foreground color.

pub fn set_fg(&mut self, color: Option<Color>) -> &mut ColorSpec

Set the foreground color.

pub fn bg(&self) -> Option<&Color>

Get the background color.

pub fn set_bg(&mut self, color: Option<Color>) -> &mut ColorSpec

Set the background color.

pub fn bold(&self) -> bool

Get whether this is bold or not.

Note that the bold setting has no effect in a Windows console.

pub fn set_bold(&mut self, yes: bool) -> &mut ColorSpec

Set whether the text is bolded or not.

Note that the bold setting has no effect in a Windows console.

pub fn dimmed(&self) -> bool

Get whether this is dimmed or not.

Note that the dimmed setting has no effect in a Windows console.

pub fn set_dimmed(&mut self, yes: bool) -> &mut ColorSpec

Set whether the text is dimmed or not.

Note that the dimmed setting has no effect in a Windows console.

pub fn italic(&self) -> bool

Get whether this is italic or not.

Note that the italic setting has no effect in a Windows console.

pub fn set_italic(&mut self, yes: bool) -> &mut ColorSpec

Set whether the text is italicized or not.

Note that the italic setting has no effect in a Windows console.

pub fn underline(&self) -> bool

Get whether this is underline or not.

Note that the underline setting has no effect in a Windows console.

pub fn set_underline(&mut self, yes: bool) -> &mut ColorSpec

Set whether the text is underlined or not.

Note that the underline setting has no effect in a Windows console.

pub fn strikethrough(&self) -> bool

Get whether this is strikethrough or not.

Note that the strikethrough setting has no effect in a Windows console.

pub fn set_strikethrough(&mut self, yes: bool) -> &mut ColorSpec

Set whether the text is strikethrough or not.

Note that the strikethrough setting has no effect in a Windows console.

pub fn reset(&self) -> bool

Get whether reset is enabled or not.

reset is enabled by default. When disabled and using ANSI escape sequences, a “reset” code will be emitted every time a ColorSpec’s settings are applied.

Note that the reset setting has no effect in a Windows console.

pub fn set_reset(&mut self, yes: bool) -> &mut ColorSpec

Set whether to reset the terminal whenever color settings are applied.

reset is enabled by default. When disabled and using ANSI escape sequences, a “reset” code will be emitted every time a ColorSpec’s settings are applied.

Typically this is useful if callers have a requirement to more scrupulously manage the exact sequence of escape codes that are emitted when using ANSI for colors.

Note that the reset setting has no effect in a Windows console.

pub fn intense(&self) -> bool

Get whether this is intense or not.

On Unix-like systems, this will output the ANSI escape sequence that will print a high-intensity version of the color specified.

On Windows systems, this will output the ANSI escape sequence that will print a brighter version of the color specified.

pub fn set_intense(&mut self, yes: bool) -> &mut ColorSpec

Set whether the text is intense or not.

On Unix-like systems, this will output the ANSI escape sequence that will print a high-intensity version of the color specified.

On Windows systems, this will output the ANSI escape sequence that will print a brighter version of the color specified.

pub fn is_none(&self) -> bool

Returns true if this color specification has no colors or styles.

pub fn clear(&mut self)

Clears this color specification so that it has no color/style settings.